@@ -1,5 +1,5 @@
 /*
- *  Copyright (C) 2015-2018 Cisco Systems, Inc. and/or its affiliates. All rights reserved.
+ *  Copyright (C) 2015-2022 Cisco Systems, Inc. and/or its affiliates. All rights reserved.
  *  Copyright (C) 2009 Sourcefire, Inc.
  *
  *  Authors: Tomasz Kojm, aCaB, Mickey Sola
@@ -57,7 +57,7 @@
 #include "str.h"
 #include "others.h"
 
-// shared
+// common
 #include "optparser.h"
 #include "output.h"
 #include "misc.h"
@@ -90,6 +90,7 @@ int onas_check_remote(struct onas_context **ctx, cl_error_t *err)
     CURLcode curlcode;
     char *ipaddr = NULL;
     int64_t timeout;
+    const char zPING[] = "zPING";
 
     timeout = optget((*ctx)->clamdopts, "OnAccessCurlTimeout")->numarg;
 
@@ -144,7 +145,7 @@ int onas_check_remote(struct onas_context **ctx, cl_error_t *err)
         }
 
 #ifndef ONAS_DEBUG
-        if (onas_sendln(curl, "zPING", 5, timeout)) {
+        if (onas_sendln(curl, zPING, sizeof(zPING), timeout)) {
             logg("!ClamClient: could not ping clamd, %s\n", curl_easy_strerror(curlcode));
             *err = CL_EARG;
             curl_easy_cleanup(curl);
@@ -178,6 +179,7 @@ int16_t onas_ping_clamd(struct onas_context **ctx)
     int b_remote   = 0;
     uint16_t ret   = 0;
     int64_t timeout;
+    const char zPING[] = "zPING";
 
     if (ctx == NULL) {
         logg("!null parameter was passed\n");
@@ -243,7 +245,7 @@ int16_t onas_ping_clamd(struct onas_context **ctx)
         curlcode = curl_easy_perform(curl);
         if (CURLE_OK != curlcode) {
             logg("*ClamClient: could not connect to clamd, %s\n", curl_easy_strerror(curlcode));
-        } else if (CURLE_OK == onas_sendln(curl, "zPING", 5, timeout)) {
+        } else if (CURLE_OK == onas_sendln(curl, zPING, sizeof(zPING), timeout)) {
 
             if (!optget((*ctx)->opts, "wait")->enabled) {
                 logg("PONG\n");
@@ -484,6 +486,7 @@ int onas_get_clamd_version(struct onas_context **ctx)
     int len;
     struct onas_rcvln rcv;
     int64_t timeout;
+    const char zVERSION[] = "zVERSION";
 
     timeout = optget((*ctx)->clamdopts, "OnAccessCurlTimeout")->numarg;
 
@@ -513,7 +516,7 @@ int onas_get_clamd_version(struct onas_context **ctx)
         return 2;
     }
 
-    if (onas_sendln(curl, "zVERSION", 9, timeout)) {
+    if (onas_sendln(curl, zVERSION, sizeof(zVERSION), timeout)) {
         curl_easy_cleanup(curl);
         return 2;
     }
