@@ -1,5 +1,5 @@
 /*
- *  Copyright (C) 2013-2020 Cisco Systems, Inc. and/or its affiliates. All rights reserved.
+ *  Copyright (C) 2013-2022 Cisco Systems, Inc. and/or its affiliates. All rights reserved.
  *  Copyright (C) 2007-2013 Sourcefire, Inc.
  *
  *  Authors: Török Edvin
@@ -326,9 +326,9 @@ static int cli_hashtab_grow(struct cli_hashtable *s)
     struct cli_element *htable;
     size_t i, idx, used = 0;
 
-    cli_dbgmsg("hashtab.c: new capacity: %llu\n", (long long unsigned)new_capacity);
+    cli_dbgmsg("hashtab.c: new capacity: %zu\n", new_capacity);
     if (new_capacity == s->capacity) {
-        cli_errmsg("hashtab.c: capacity problem growing from: %llu\n", (long long unsigned)s->capacity);
+        cli_errmsg("hashtab.c: capacity problem growing from: %zu\n", s->capacity);
         return CL_EMEM;
     }
     htable = cli_calloc(new_capacity, sizeof(*s->htable));
@@ -368,7 +368,7 @@ static int cli_hashtab_grow(struct cli_hashtable *s)
     s->used     = used;
     s->capacity = new_capacity;
     s->maxfill  = new_capacity * 8 / 10;
-    cli_dbgmsg("Table %p size after grow:%llu\n", (void *)s, (long long unsigned)s->capacity);
+    cli_dbgmsg("Table %p size after grow: %zu\n", (void *)s, s->capacity);
     PROFILE_GROW_DONE(s);
     return CL_SUCCESS;
 }
@@ -382,7 +382,7 @@ static int cli_htu32_grow(struct cli_htu32 *s, mpool_t *mempool)
     const size_t new_capacity        = nearest_power(s->capacity + 1);
     struct cli_htu32_element *htable = MPOOL_CALLOC(mempool, new_capacity, sizeof(*s->htable));
     size_t i, idx, used = 0;
-    cli_dbgmsg("hashtab.c: new capacity: %llu\n", (long long unsigned)new_capacity);
+    cli_dbgmsg("hashtab.c: new capacity: %zu\n", new_capacity);
     if (new_capacity == s->capacity || !htable)
         return CL_EMEM;
 
@@ -417,7 +417,7 @@ static int cli_htu32_grow(struct cli_htu32 *s, mpool_t *mempool)
     s->used     = used;
     s->capacity = new_capacity;
     s->maxfill  = new_capacity * 8 / 10;
-    cli_dbgmsg("Table %p size after grow:%llu\n", (void *)s, (long long unsigned)s->capacity);
+    cli_dbgmsg("Table %p size after grow: %zu\n", (void *)s, s->capacity);
     PROFILE_GROW_DONE(s);
     return CL_SUCCESS;
 }
@@ -431,7 +431,7 @@ const struct cli_element *cli_hashtab_insert(struct cli_hashtable *s, const char
     if (!s)
         return NULL;
     if (s->used > s->maxfill) {
-        cli_dbgmsg("hashtab.c:Growing hashtable %p, because it has exceeded maxfill, old size:%llu\n", (void *)s, (long long unsigned)s->capacity);
+        cli_dbgmsg("hashtab.c:Growing hashtable %p, because it has exceeded maxfill, old size: %zu\n", (void *)s, s->capacity);
         cli_hashtab_grow(s);
     }
     do {
@@ -476,7 +476,7 @@ const struct cli_element *cli_hashtab_insert(struct cli_hashtable *s, const char
         } while (tries <= s->capacity);
         /* no free place found*/
         PROFILE_HASH_EXHAUSTED(s);
-        cli_dbgmsg("hashtab.c: Growing hashtable %p, because its full, old size:%llu.\n", (void *)s, (long long unsigned)s->capacity);
+        cli_dbgmsg("hashtab.c: Growing hashtable %p, because its full, old size: %zu.\n", (void *)s, s->capacity);
     } while (cli_hashtab_grow(s) >= 0);
     cli_warnmsg("hashtab.c: Unable to grow hashtable\n");
     return NULL;
@@ -493,7 +493,7 @@ int cli_htu32_insert(struct cli_htu32 *s, const struct cli_htu32_element *item,
     if (!s)
         return CL_ENULLARG;
     if (s->used > s->maxfill) {
-        cli_dbgmsg("hashtab.c:Growing hashtable %p, because it has exceeded maxfill, old size:%llu\n", (void *)s, (long long unsigned)s->capacity);
+        cli_dbgmsg("hashtab.c:Growing hashtable %p, because it has exceeded maxfill, old size: %zu\n", (void *)s, s->capacity);
         cli_htu32_grow(s, mempool);
     }
     do {
@@ -528,7 +528,7 @@ int cli_htu32_insert(struct cli_htu32 *s, const struct cli_htu32_element *item,
         } while (tries <= s->capacity);
         /* no free place found*/
         PROFILE_HASH_EXHAUSTED(s);
-        cli_dbgmsg("hashtab.c: Growing hashtable %p, because its full, old size:%llu.\n", (void *)s, (long long unsigned)s->capacity);
+        cli_dbgmsg("hashtab.c: Growing hashtable %p, because its full, old size: %zu.\n", (void *)s, s->capacity);
     } while ((ret = cli_htu32_grow(s, mempool)) >= 0);
     cli_warnmsg("hashtab.c: Unable to grow hashtable\n");
     return ret;
@@ -598,7 +598,7 @@ int cli_hashtab_store(const struct cli_hashtable *s, FILE *out)
     for (i = 0; i < s->capacity; i++) {
         const struct cli_element *e = &s->htable[i];
         if (e->key && e->key != DELETED_KEY) {
-            fprintf(out, "%ld %s\n", e->data, e->key);
+            fprintf(out, "%zu %s\n", (size_t)e->data, e->key);
         }
     }
     return CL_SUCCESS;
@@ -617,12 +617,11 @@ int cli_hashtab_generate_c(const struct cli_hashtable *s, const char *name)
         else if (e->key == DELETED_KEY)
             printf("\t{DELETED_KEY,0,0},\n");
         else
-            printf("\t{\"%s\", %ld, %llu},\n", e->key, e->data, (long long unsigned)e->len);
+            printf("\t{\"%s\", %zu, %zu},\n", e->key, (size_t)e->data, e->len);
     }
     printf("};\n");
     printf("const struct cli_hashtable %s = {\n", name);
-    printf("\t%s_elements, %llu, %llu, %llu", name, (long long unsigned)s->capacity,
-           (long long unsigned)s->used, (long long unsigned)s->maxfill);
+    printf("\t%s_elements, %zu, %zu, %zu", name, s->capacity, s->used, s->maxfill);
     printf("\n};\n");
 
     PROFILE_REPORT(s);
@@ -634,9 +633,9 @@ int cli_hashtab_load(FILE *in, struct cli_hashtable *s)
     char line[1024];
     while (fgets(line, sizeof(line), in)) {
         char l[1024];
-        int val;
-        sscanf(line, "%d %1023s", &val, l);
-        cli_hashtab_insert(s, l, strlen(l), val);
+        size_t val;
+        sscanf(line, "%zu %1023s", &val, l);
+        cli_hashtab_insert(s, l, strlen(l), (const cli_element_data)val);
     }
     return CL_SUCCESS;
 }
@@ -859,13 +858,13 @@ int cli_map_init(struct cli_map *m, int32_t keysize, int32_t valuesize,
 
 int cli_map_addkey(struct cli_map *m, const void *key, int32_t keysize)
 {
-    unsigned n;
+    uint32_t n;
     struct cli_element *el;
     if (m->keysize != keysize)
         return -CL_EARG;
     el = cli_hashtab_find(&m->htab, key, keysize);
     if (el) {
-        m->last_insert = el->data;
+        m->last_insert = (int32_t)el->data;
         return 0;
     }
     n = m->nvalues + 1;
@@ -885,7 +884,7 @@ int cli_map_addkey(struct cli_map *m, const void *key, int32_t keysize)
         memset(&m->u.unsized_values[n - 1], 0, sizeof(*m->u.unsized_values));
     }
     m->nvalues = n;
-    if (!cli_hashtab_insert(&m->htab, key, keysize, n - 1))
+    if (!cli_hashtab_insert(&m->htab, key, keysize, (const cli_element_data)(n - 1)))
         return -CL_EMEM;
     m->last_insert = n - 1;
     return 1;
@@ -899,15 +898,15 @@ int cli_map_removekey(struct cli_map *m, const void *key, int32_t keysize)
     el = cli_hashtab_find(&m->htab, key, keysize);
     if (!el)
         return 0;
-    if (el->data >= m->nvalues || el->data < 0)
+    if ((int32_t)el->data >= (int32_t)m->nvalues || (int32_t)el->data < 0)
         return -CL_EARG;
     if (!m->valuesize) {
-        struct cli_map_value *v = &m->u.unsized_values[el->data];
+        struct cli_map_value *v = &m->u.unsized_values[(int32_t)el->data];
         free(v->value);
         v->value     = NULL;
         v->valuesize = 0;
     } else {
-        char *v = (char *)m->u.sized_values + el->data * m->valuesize;
+        char *v = (char *)m->u.sized_values + (int32_t)el->data * m->valuesize;
         memset(v, 0, m->valuesize);
     }
     cli_hashtab_delete(&m->htab, key, keysize);
@@ -944,7 +943,7 @@ int cli_map_find(struct cli_map *m, const void *key, int32_t keysize)
     el = cli_hashtab_find(&m->htab, key, keysize);
     if (!el)
         return 0;
-    m->last_find = el->data;
+    m->last_find = (int32_t)el->data;
     return 1;
 }
 
